@@ -9,6 +9,8 @@ For an overview of the kcu types see :ref:`kcu-label`.
 """
 
 
+import warnings
+
 import numpy as np
 
 from threedigrid.admin.lines import exporters, subsets
@@ -39,27 +41,42 @@ class Lines(Model):
 
     """
 
-    kcu = ArrayField()
-    lik = ArrayField()
+    kcu = ArrayField(type=int)
+    lik = ArrayField(type=int)
     line = IndexArrayField(to="Nodes")
-    dpumax = ArrayField()
-    flod = ArrayField()
-    flou = ArrayField()
+    dpumax = ArrayField(type=float)
+    flod = ArrayField(type=float)
+    flou = ArrayField(type=float)
     cross1 = IndexArrayField(to="CrossSections")
     cross2 = IndexArrayField(to="CrossSections")
-    ds1d = ArrayField()
-    ds1d_half = ArrayField()
-    cross_weight = ArrayField()
-    invert_level_start_point = ArrayField()
-    invert_level_end_point = ArrayField()
-    content_pk = ArrayField()
-    content_type = ArrayField()
-    zoom_category = ArrayField()
+    ds1d = ArrayField(type=float)
+    ds1d_half = ArrayField(type=float)
+    cross_weight = ArrayField(type=float)
+    invert_level_start_point = ArrayField(type=float)
+    invert_level_end_point = ArrayField(type=float)
+    content_pk = ArrayField(type=int)
+    content_type = ArrayField(type=str)
+    zoom_category = ArrayField(type=int)
     cross_pix_coords = LineArrayField()
     line_coords = LineArrayField()
     line_geometries = MultiLineArrayField()
     SUBSETS = LINE_SUBSETS
 
+    GPKG_DEFAULT_FIELD_MAP = {
+        "id": "id",
+        "flou": "discharge_coefficient_positive",
+        "flod": "discharge_coefficient_negative",
+        "kcu": "line_type",
+        "content_type": "source_table",
+        "content_pk": "source_table_id",
+        "invert_level_start_point": "invert_level_start_point",
+        "invert_level_end_point": "invert_level_end_point",
+        "dpumax": "exchange_level",
+        "line__0": "calculation_node_id_start",
+        "line__1": "calculation_node_id_end",
+        "line_geometries": "the_geom",
+    }
+
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -89,6 +106,11 @@ class Lines(Model):
 
     @property
     def breaches(self):
+        warnings.warn(
+            "lines.breaches is going to be removed "
+            " in the near future, please use the root breaches instead",
+            UserWarning,
+        )
         return self._filter_as(Breaches, kcu=55)
 
     @property
@@ -97,44 +119,44 @@ class Lines(Model):
 
 
 class Pipes(Lines):
-    display_name = ArrayField()
-    friction_type = ArrayField()
-    friction_value = ArrayField()
-    material = ArrayField()
-    cross_section_height = ArrayField()
-    cross_section_width = ArrayField()
-    cross_section_shape = ArrayField()
-    sewerage_type = ArrayField()
-    calculation_type = ArrayField()
-    connection_node_start_pk = ArrayField()
-    connection_node_end_pk = ArrayField()
-    discharge_coefficient = ArrayField()
+    display_name = ArrayField(type=str)
+    friction_type = ArrayField(type=int)
+    friction_value = ArrayField(type=float)
+    material = ArrayField(type=int)
+    cross_section_height = ArrayField(type=float)
+    cross_section_width = ArrayField(type=float)
+    cross_section_shape = ArrayField(type=float)
+    sewerage_type = ArrayField(type=int)
+    calculation_type = ArrayField(type=int)
+    connection_node_start_pk = ArrayField(type=int)
+    connection_node_end_pk = ArrayField(type=int)
+    discharge_coefficient = ArrayField(type=float)
 
 
 class Channels(Lines):
-    code = ArrayField()
-    calculation_type = ArrayField()
-    dist_calc_points = ArrayField()
-    connection_node_start_pk = ArrayField()
-    connection_node_end_pk = ArrayField()
-    discharge_coefficient = ArrayField()
+    code = ArrayField(type=str)
+    calculation_type = ArrayField(type=int)
+    dist_calc_points = ArrayField(type=float)
+    connection_node_start_pk = ArrayField(type=int)
+    connection_node_end_pk = ArrayField(type=int)
+    discharge_coefficient = ArrayField(type=float)
 
 
 class Weirs(Lines):
-    code = ArrayField()
-    display_name = ArrayField()
-    discharge_coefficient_negative = ArrayField()
-    discharge_coefficient_positive = ArrayField()
-    sewerage = ArrayField()
-    friction_type = ArrayField()
-    friction_value = ArrayField()
-    crest_type = ArrayField()
-    crest_level = ArrayField()
-    connection_node_start_pk = ArrayField()
-    connection_node_end_pk = ArrayField()
-    cross_section_height = ArrayField()
-    cross_section_width = ArrayField()
-    cross_section_shape = ArrayField()
+    code = ArrayField(type=str)
+    display_name = ArrayField(type=str)
+    discharge_coefficient_negative = ArrayField(type=float)
+    discharge_coefficient_positive = ArrayField(type=float)
+    sewerage = ArrayField(type=int)
+    friction_type = ArrayField(type=int)
+    friction_value = ArrayField(type=float)
+    crest_type = ArrayField(type=int)
+    crest_level = ArrayField(type=float)
+    connection_node_start_pk = ArrayField(type=int)
+    connection_node_end_pk = ArrayField(type=int)
+    cross_section_height = ArrayField(type=float)
+    cross_section_width = ArrayField(type=float)
+    cross_section_shape = ArrayField(type=float)
 
     @property
     def line_coord_angles(self):
@@ -153,32 +175,32 @@ class Weirs(Lines):
 
 
 class Culverts(Lines):
-    display_name = ArrayField()
-    code = ArrayField()
-    calculation_type = ArrayField()
-    dist_calc_points = ArrayField()
-    cross_section_height = ArrayField()
-    cross_section_width = ArrayField()
-    cross_section_shape = ArrayField()
-    friction_type = ArrayField()
-    friction_value = ArrayField()
-    discharge_coefficient_negative = ArrayField()
-    discharge_coefficient_positive = ArrayField()
-    connection_node_start_pk = ArrayField()
-    connection_node_end_pk = ArrayField()
+    display_name = ArrayField(type=str)
+    code = ArrayField(type=str)
+    calculation_type = ArrayField(type=int)
+    dist_calc_points = ArrayField(type=float)
+    cross_section_height = ArrayField(type=float)
+    cross_section_width = ArrayField(type=float)
+    cross_section_shape = ArrayField(type=float)
+    friction_type = ArrayField(type=int)
+    friction_value = ArrayField(type=float)
+    discharge_coefficient_negative = ArrayField(type=float)
+    discharge_coefficient_positive = ArrayField(type=float)
+    connection_node_start_pk = ArrayField(type=int)
+    connection_node_end_pk = ArrayField(type=int)
 
 
 class Orifices(Lines):
-    display_name = ArrayField()
-    sewerage = ArrayField()
-    friction_type = ArrayField()
-    friction_value = ArrayField()
-    crest_type = ArrayField()
-    crest_level = ArrayField()
-    discharge_coefficient_negative = ArrayField()
-    discharge_coefficient_positive = ArrayField()
-    connection_node_start_pk = ArrayField()
-    connection_node_end_pk = ArrayField()
+    display_name = ArrayField(type=str)
+    sewerage = ArrayField(type=int)
+    friction_type = ArrayField(type=int)
+    friction_value = ArrayField(type=float)
+    crest_type = ArrayField(type=int)
+    crest_level = ArrayField(type=float)
+    discharge_coefficient_negative = ArrayField(type=float)
+    discharge_coefficient_positive = ArrayField(type=float)
+    connection_node_start_pk = ArrayField(type=int)
+    connection_node_end_pk = ArrayField(type=int)
 
 
 class Breaches(Lines):
@@ -224,5 +246,5 @@ class Breaches(Lines):
         subset_filter={"lines.kcu": subsets.KCU__IN_SUBSETS["POTENTIAL_BREACH"][0]},
     )
 
-    discharge_coefficient_positive = ArrayField()
-    discharge_coefficient_negative = ArrayField()
+    discharge_coefficient_positive = ArrayField(type=float)
+    discharge_coefficient_negative = ArrayField(type=float)
